<?php
/*
Plugin Name: Product Search With Autosuggest For WooCommerce
Description: Add a search bar with autosuggest for WooCommerce products, with category filtering.
Author: Primary Digital Marketing (PrimaryDM)
Version: 1.0
*/

// Add settings link on the Plugins page
function product_searchbar_for_woocommerce_settings_link($links) {
    $settings_link = '<a href="admin.php?page=product-searchbar-for-woocommerce-settings">Settings</a>';
    array_unshift($links, $settings_link);
    return $links;
}
$plugin = plugin_basename(__FILE__);
add_filter("plugin_action_links_$plugin", 'product_searchbar_for_woocommerce_settings_link');

// Register the shortcode [product_search]
function product_searchbar_for_woocommerce_shortcode($atts) {
    $attributes = shortcode_atts(array(
        'category' => '',
    ), $atts);

    ob_start();
    ?>
    <div class="product-search-container">
        <input type="text" id="product-search-input" placeholder="Search for products" data-category="<?php echo esc_attr($attributes['category']); ?>">
        <div class="product-suggestions"></div>
    </div>
    <script>
        jQuery(document).ready(function($) {
            $('#product-search-input').on('input', function() {
                var query = $(this).val();
                var category = $(this).data('category');
                if (query.length >= 2) {
                    $.ajax({
                        url: '<?php echo admin_url('admin-ajax.php'); ?>',
                        type: 'POST',
                        data: {
                            action: 'product_search',
                            query: query,
                            category: category
                        },
                        success: function(response) {
                            $('.product-suggestions').html(response);
                        }
                    });
                } else {
                    $('.product-suggestions').empty();
                }
            });
        });
    </script>
    <?php
    return ob_get_clean();
}
add_shortcode('product_search', 'product_searchbar_for_woocommerce_shortcode');

// Handle AJAX requests to search for products
function product_search_callback() {
    $query = sanitize_text_field($_POST['query']);
    $category = sanitize_text_field($_POST['category']);

    $args = array(
        's' => $query,
    );

    if (!empty($category)) {
        $args['category'] = explode(',', $category);
    }

    $products = wc_get_products($args);

    if (!empty($products)) {
        foreach ($products as $product) {
            $product_name = esc_html($product->get_name());
            $suggested_name = preg_replace("/($query)/i", '<strong>$1</strong>', $product_name);
            $product_image = $product->get_image(array(32, 32));

            echo '<div class="product-suggestion">';
            echo '<div class="product-suggestion-image">' . $product_image . '</div>';
            echo '<div class="product-suggestion-title">';
            echo '<a href="' . get_permalink($product->get_id()) . '">' . $suggested_name . '</a>';
            echo '</div>';
            echo '</div>';
        }
    } else {
        echo '<div class="no-results">No results found</div>';
    }
    wp_die();
}
add_action('wp_ajax_product_search', 'product_search_callback');
add_action('wp_ajax_nopriv_product_search', 'product_search_callback');

// Enqueue external CSS file
function product_searchbar_for_woocommerce_enqueue_styles() {
    wp_enqueue_style('product-searchbar-for-woocommerce-styles', plugins_url('style.css', __FILE__));
}
add_action('wp_enqueue_scripts', 'product_searchbar_for_woocommerce_enqueue_styles');


?>
